==> ofscraper-3.10.19.tar.gz: ofscraper-3.10.19/ofscraper/const/values/config.py <==
import os
import pathlib

SANITIZE_DB_DEFAULT = False
SUPPRESS_LOG_LEVEL = 21
RESUME_DEFAULT = True
CACHEDEFAULT = "sqlite"
KEY_DEFAULT = "cdrm"
DIR_FORMAT_DEFAULT = "{model_username}/{responsetype}/{mediatype}/"
FILE_FORMAT_DEFAULT = "{filename}.{ext}"
METADATA_DEFAULT = "{configpath}/{profile}/.data/{model_username}_{model_id}"
FILE_SIZE_MAX_DEFAULT = 0
FILE_SIZE_MIN_DEFAULT = 0
MIN_LENGTH_DEFAULT = 0
MAX_LENGTH_DEFAULT = 0
TEXTLENGTH_DEFAULT = 0
SPACE_REPLACER_DEFAULT = " "
PROGRESS_DEFAULT = False
FILTER_DEFAULT = ["Images", "Audios", "Videos"]
SAVE_PATH_DEFAULT = str(pathlib.Path.home() / "Data/ofscraper")
DATE_DEFAULT = "MM-DD-YYYY"
PROFILE_DEFAULT = "main_profile"
PREMIUM_DEFAULT = "Premium"
KEYDB_DEFAULT = ""
FFMPEG_DEFAULT = ""
DISCORD_DEFAULT = ""
BACKEND_DEFAULT = "aio"
THREADS_DEFAULT = 2
DOWNLOAD_SEM_DEFAULT = 10
DYNAMIC_DEFAULT = "deviint"
TEXT_TYPE_DEFAULT = "letter"
TRUNCATION_DEFAULT = True
MAX_COUNT_DEFAULT = 0
TEMP_FOLDER_DEFAULT = None
APPEND_DEFAULT = True
RESPONSE_TYPE_DEFAULT = {
    "message": "Messages",
    "timeline": "Posts",
    "archived": "Archived",
    "paid": "Messages",
    "stories": "Stories",
    "highlights": "Stories",
    "profile": "Profile",
    "pinned": "Posts",
    "streams": "Streams",
}
SYSTEM_FREEMIN_DEFAULT = 0
AVATAR_DEFAULT = True
havROGRESS_DEFAULT = False
KEYDB_DEFAULT = ""
CODE_EXECUTION_DEFAULT = False
INFINITE_LOOP_DEFAULT = False
ENABLE_AUTO_AFTER_DEFAULT = False
DEFAULT_USER_LIST = "main"
DEFAULT_BLACK_LIST = ""
HASHED_DEFAULT = None
BLOCKED_ADS_DEFAULT = False
EMPTY_MEDIA_DEFAULT = {}
DEFAULT_LOG_LEVEL = "DEBUG"
INCLUDE_LABELS_ALL = False
DISCORD_THREAD_OVERRIDE = False
DISCORD_ASYNC = False
USE_WIV_CACHE_KEY = True
POST_SCRIPT_DEFAULT = None

==> ofscraper-3.11.tar.gz: ofscraper-3.11/ofscraper/const/values/config.py <==
import os
import pathlib

SANITIZE_DB_DEFAULT = False
SUPPRESS_LOG_LEVEL = 21
RESUME_DEFAULT = True
CACHEDEFAULT = "sqlite"
KEY_DEFAULT = "cdrm"
DIR_FORMAT_DEFAULT = "{model_username}/{responsetype}/{mediatype}/"
FILE_FORMAT_DEFAULT = "{filename}.{ext}"
METADATA_DEFAULT = "{configpath}/{profile}/.data/{model_id}"
FILE_SIZE_MAX_DEFAULT = 0
FILE_SIZE_MIN_DEFAULT = 0
MIN_LENGTH_DEFAULT = 0
MAX_LENGTH_DEFAULT = 0
TEXTLENGTH_DEFAULT = 0
SPACE_REPLACER_DEFAULT = " "
PROGRESS_DEFAULT = False
FILTER_DEFAULT = ["Images", "Audios", "Videos"]
SAVE_PATH_DEFAULT = str(pathlib.Path.home() / "Data/ofscraper")
DATE_DEFAULT = "MM-DD-YYYY"
PROFILE_DEFAULT = "main_profile"
PREMIUM_DEFAULT = "Premium"
KEYDB_DEFAULT = ""
FFMPEG_DEFAULT = ""
DISCORD_DEFAULT = ""
BACKEND_DEFAULT = "aio"
THREADS_DEFAULT = 2
DOWNLOAD_SEM_DEFAULT = 6
DYNAMIC_DEFAULT = "deviint"
TEXT_TYPE_DEFAULT = "letter"
TRUNCATION_DEFAULT = True
MAX_COUNT_DEFAULT = 0
TEMP_FOLDER_DEFAULT = None
APPEND_DEFAULT = True
RESPONSE_TYPE_DEFAULT = {
    "message": "Messages",
    "timeline": "Posts",
    "archived": "Archived",
    "paid": "Messages",
    "stories": "Stories",
    "highlights": "Stories",
    "profile": "Profile",
    "pinned": "Posts",
    "streams": "Streams",
}
SYSTEM_FREEMIN_DEFAULT = 0
AVATAR_DEFAULT = True
havROGRESS_DEFAULT = False
KEYDB_DEFAULT = ""
CODE_EXECUTION_DEFAULT = False
INFINITE_LOOP_DEFAULT = False
ENABLE_AUTO_AFTER_DEFAULT = False
DEFAULT_USER_LIST = "main"
DEFAULT_BLACK_LIST = ""
HASHED_DEFAULT = None
BLOCKED_ADS_DEFAULT = False
EMPTY_MEDIA_DEFAULT = {}
DEFAULT_LOG_LEVEL = "DEBUG"
INCLUDE_LABELS_ALL = False
DISCORD_THREAD_OVERRIDE = False
DISCORD_ASYNC = False
USE_WIV_CACHE_KEY = True
POST_SCRIPT_DEFAULT = None
